Documentation
¶
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
This section is empty.
Types ¶
type Exporter ¶
type Exporter struct {
// Container is the name of your Azure Blob Storage Container similar to Buckets in S3.
Container string
// Storage Account Name and Key
AccountName string
AccountKey string
Format string
Path string
Filename string
CsvTemplate string
ParquetCompressionCodec string
// ServiceURL is the URL of the storage account e.g. https://<account>.blob.core.windows.net/
// It can be overridden by the user to use a custom URL.
// Default: https://<account>.blob.core.windows.net/
ServiceURL string
}
Click to show internal directories.
Click to hide internal directories.