Documentation
¶
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
This section is empty.
Types ¶
type Exporter ¶
type Exporter struct {
// Format is the template configuration of the output format of your log.
// You can use all the key from the exporter.FeatureEvent + a key called FormattedDate that represent the date with
// the RFC 3339 Format
// Default: [{{ .FormattedDate}}] user="{{ .UserKey}}", flag="{{ .Key}}", value="{{ .Value}}"
Format string // Deprecated: use LogFormat instead.
// Format is the template configuration of the output format of your log.
// You can use all the key from the exporter.FeatureEvent + a key called FormattedDate that represent the date with
// the RFC 3339 Format
// Default: [{{ .FormattedDate}}] user="{{ .UserKey}}", flag="{{ .Key}}", value="{{ .Value}}"
LogFormat string
// contains filtered or unexported fields
}
Click to show internal directories.
Click to hide internal directories.