pubsubexporter

package
v1.55.1 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Jul 13, 2026 License: MIT Imports: 6 Imported by: 0

Documentation

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

This section is empty.

Types

type Exporter deprecated

type Exporter struct {
	// ProjectID is a project to which the PubSub topic belongs.
	ProjectID string

	// Topic is the name of a topic on which messages will be published.
	Topic string

	// Options are Google Cloud API options to connect to PubSub.
	Options []option.ClientOption

	// PublishSettings controls the bundling of published messages.
	// If not set pubsub.DefaultPublishSettings are used.
	PublishSettings *pubsub.PublishSettings

	// EnableMessageOrdering enables the delivery of ordered keys.
	EnableMessageOrdering bool
	// contains filtered or unexported fields
}

Exporter publishes events on a PubSub topic.

Deprecated: Use pubsubexporterv2.Exporter instead. This exporter uses the legacy cloud.google.com/go/pubsub v1 library. The v2 library provides improved performance and additional features. This exporter will be removed in a future version.

func (*Exporter) Export

func (e *Exporter) Export(
	ctx context.Context,
	_ *fflog.FFLogger,
	events []exporter.ExportableEvent,
) error

Export publishes a PubSub message for each exporter.FeatureEvent received.

func (*Exporter) IsBulk

func (e *Exporter) IsBulk() bool

IsBulk always returns false as PubSub exporter sends each exporter.FeatureEvent as a separate message.

Jump to