Documentation
¶
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
This section is empty.
Types ¶
type Exporter
deprecated
type Exporter struct {
// Bucket is the name of your Exporter Bucket.
Bucket string
// AwsConfig is the AWS SDK configuration object we will use to
// upload your exported data files.
AwsConfig *aws.Config
// Format is the output format you want in your exported file.
// Available format are JSON, CSV and Parquet.
// Default: JSON
Format string
// S3Path allows you to specify in which directory you want to export your data.
S3Path string
// Filename is the name of your output file
// You can use a templated config to define the name of your export files.
// Available replacement are {{ .Hostname}}, {{ .Timestamp}} and {{ .Format}}
// Default: "flag-variation-{{ .Hostname}}-{{ .Timestamp}}.{{ .Format}}"
Filename string
// CsvTemplate is used if your output format is CSV.
// This field will be ignored if you are using another format than CSV.
// You can decide which fields you want in your CSV line with a go-template syntax,
// please check internal/exporter/feature_event.go to see what are the fields available.
// Default:
// {{ .Kind}};{{ .ContextKind}};{{ .UserKey}};{{ .CreationDate}};{{ .Key}};{{ .Variation}};{{ .Value}};{{ .Default}}\n
CsvTemplate string
// ParquetCompressionCodec is the parquet compression codec for better space efficiency.
// Available options https://github.com/apache/parquet-format/blob/master/Compression.md
// Default: SNAPPY
ParquetCompressionCodec string
// contains filtered or unexported fields
}
Deprecated: Please use s3exporterv2.Exporter instead, it will use the go-aws-sdk-v2.
Click to show internal directories.
Click to hide internal directories.