Documentation
¶
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
This section is empty.
Types ¶
type Cache ¶ added in v0.6.0
type Cache interface {
// Copy return a copy version of the cache.
Copy() Cache
// All return the complete list of the flags.
All() map[string]flag.Flag
// Init allow to initialize the cache with a collection of flags.
Init(flags map[string]dto.DTO)
// contains filtered or unexported methods
}
Cache is the interface to represent a cache in the system.
type InMemoryCache ¶ added in v0.18.4
type InMemoryCache struct {
Flags map[string]flag.InternalFlag
Logger *fflog.FFLogger
}
func NewInMemoryCache ¶ added in v0.18.4
func NewInMemoryCache(logger *fflog.FFLogger) *InMemoryCache
func (*InMemoryCache) Copy ¶ added in v0.18.4
func (fc *InMemoryCache) Copy() Cache
type Manager ¶ added in v0.18.4
type Manager interface {
ConvertToFlagStruct(loadedFlags []byte, fileFormat string) (map[string]dto.DTO, error)
UpdateCache(newFlags map[string]dto.DTO, log *fflog.FFLogger, notifyChanges bool) error
Close()
GetFlag(key string) (flag.Flag, error)
AllFlags() (map[string]flag.Flag, error)
GetLatestUpdateDate() time.Time
}
Click to show internal directories.
Click to hide internal directories.