Documentation
¶
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
This section is empty.
Types ¶
type BoolVarResult ¶ added in v0.17.0
type BoolVarResult struct {
VariationResult
Value bool
}
BoolVarResult is the internal result format of a bool variation. This is used by the ffclient.BoolVariation functions and by the ffclient.AllFlagsState function
type Float64VarResult ¶ added in v0.17.0
type Float64VarResult struct {
VariationResult
Value float64
}
Float64VarResult is the internal result format of a float64 variation. This is used by the ffclient.Float64Variation functions and by the ffclient.AllFlagsState function
type IntVarResult ¶ added in v0.17.0
type IntVarResult struct {
VariationResult
Value int
}
IntVarResult is the internal result format of a int variation. This is used by the ffclient.IntVariation functions and by the ffclient.AllFlagsState function
type JSONArrayVarResult ¶ added in v0.17.0
type JSONArrayVarResult struct {
VariationResult
Value []interface{}
}
JSONArrayVarResult is the internal result format of a json array variation. This is used by the ffclient.JSONArrayVariation functions and by the ffclient.AllFlagsState function
type JSONVarResult ¶ added in v0.17.0
type JSONVarResult struct {
VariationResult
Value map[string]interface{}
}
JSONVarResult is the internal result format of a json variation. This is used by the ffclient.JSONVariation functions and by the ffclient.AllFlagsState function
type RawVarResult ¶ added in v0.22.2
type RawVarResult struct {
VariationResult
Value interface{} `json:"value"`
}
RawVarResult is the result of the raw variation call. This is used by ffclient.RawVariation functions, this should be used only by internal calls.
type StringVarResult ¶ added in v0.17.0
type StringVarResult struct {
VariationResult
Value string
}
StringVarResult is the internal result format of a string variation. This is used by the ffclient.StringVariation functions and by the ffclient.AllFlagsState function