Documentation
¶
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
This section is empty.
Types ¶
type Retriever ¶
type Retriever struct {
// Bucket is the name of your Google Cloud Storage Bucket.
Bucket string
// Object is the name of your file in your bucket.
Object string
// Options are Google Cloud Api options needed for downloading
// your feature flag configuration file.
Options []option.ClientOption
// contains filtered or unexported fields
}
Retriever is a configuration struct for a Google Cloud Storage retriever.
func (*Retriever) SetOptions ¶ added in v1.48.0
func (retriever *Retriever) SetOptions(options []option.ClientOption)
Click to show internal directories.
Click to hide internal directories.