Documentation
¶
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
This section is empty.
Types ¶
type DownloaderAPI ¶
type DownloaderAPI interface {
Download(ctx context.Context, w io.WriterAt, input *s3.GetObjectInput, options ...func(*manager.Downloader)) (
n int64, err error)
}
DownloaderAPI provides methods to manage downloads to an S3 bucket.
type Retriever ¶
type Retriever struct {
// Bucket is the name of your S3 Bucket.
Bucket string
// Item is the path to your flag file in your bucket.
Item string
// AwsConfig is the AWS SDK configuration object we will use to
// download your feature flag configuration file.
AwsConfig *aws.Config
// contains filtered or unexported fields
}
Retriever is a configuration struct for a S3 retriever.
Click to show internal directories.
Click to hide internal directories.