Documentation
¶
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
This section is empty.
Types ¶
type Cache ¶ added in v0.6.0
type Cache interface {
// Copy return a copy version of the cache.
Copy() Cache
// All return the complete list of the flags.
All() map[string]flag.Flag
// Init allow to initialize the cache with a collection of flags.
Init(flags map[string]flagv1.FlagData)
// contains filtered or unexported methods
}
Cache is the interface to represent a cache in the system.
type InMemoryCache ¶ added in v0.18.4
func NewInMemoryCache ¶ added in v0.18.4
func NewInMemoryCache() *InMemoryCache
func (*InMemoryCache) Copy ¶ added in v0.18.4
func (fc *InMemoryCache) Copy() Cache
Click to show internal directories.
Click to hide internal directories.